#!/bin/bash
#
# Script to collect DDN VM configuration information.
# Output file is left in current working directory.
# Must be run as root.
#

VERSION=20140312-01
OUTPUT=$(basename ${0}).$(hostname -s)

if [[ "$(/usr/bin/whoami)" != "root" ]]; then
	echo "ERROR: must be run as root.  Exiting."
	exit 1
fi


(
	export PATH=/sbin/:/usr/sbin:${PATH}
	echo "$(basename ${0}) version ${VERSION}"
	set -x

	date
	hostname
	for release in /etc/*-release; do
		cat ${release}
	done
	uname -a
	uptime
	free -mt
	sfactrl i

	ifconfig -a
	netstat -ian
	netstat -rn

	ofed_info
	ibstat
	for cfg in /etc/modprobe.d/mlx4*.conf; do
		cat ${cfg}
	done
	for module in mlx4_core mlx4_ib mlx4_en sfablkdriver; do
		cat /sys/module/${module}/version
		cat /sys/module/${module}/srcversion
		for param in /sys/module/${module}/parameters/*; do
			cat ${param}
		done
	done

	devices=$(sed -n 's/^.*\(eth[0-9]\).*$/\1/p' /proc/net/dev)
	for device in ${devices}; do
		ethtool ${device}
		ethtool --show-pause ${device}
		ethtool --show-coalesce ${device}
		ethtool --show-ring ${device}
		ethtool --driver ${device}
		ethtool --show-offload ${device}
		ethtool --show-nfc ${device}
	done

	cat /etc/ntp.conf
	cat /etc/ntp/step-tickers
	ntpq -c pe

	sysctl -a | sort

	rpms=$(rpm -qa | sort)
	for rpm in ${rpms}; do
		rpm -qi ${rpm}
	done
	rpm -qaV

	for device in /sys/block/sfa*; do
		cat ${device}/oid
		for param in ${device}/queue/*; do
			cat ${param}
		done
		for param in ${device}/queue/iosched/*; do
			cat ${param}
		done
	done

	dmesg
	cat /var/log/messages
	cat /proc/interrupts
	cat /proc/meminfo
	cat /proc/zoneinfo
	cat /proc/vmstat
	cat /proc/slabinfo
	cat /proc/modules
	cat /proc/cpuinfo
	cat /proc/cgroups
	cat /proc/cmdline
	cat /proc/diskstats
	cat /proc/scsi/scsi
	zcat /proc/config.gz

) 2>&1 | tee ${OUTPUT}

echo
echo "Output file is ${OUTPUT}"
